@@ -341,10 +341,20 @@ class NodeNetworkConfigurationPolicy(Resource):
             if condition["type"] == self.Conditions.Type.AVAILABLE:
                 return condition["reason"]
 
-    def _wait_for_configuration_progressing(self):
-        samples = TimeoutSampler(wait_timeout=30, sleep=1, func=self.status)
+    def _wait_for_configuration_conditions_unknown_or_progressing(self):
+        samples = TimeoutSampler(
+            wait_timeout=30, sleep=1, func=lambda: self.instance.status.conditions
+        )
         for sample in samples:
-            if sample and sample == self.Conditions.Reason.CONFIGURATION_PROGRESSING:
+            if (
+                sample
+                and sample[0]["type"] == self.Conditions.Type.AVAILABLE
+                and (
+                    sample[0]["status"] == self.Condition.Status.UNKNOWN
+                    or sample[0]["reason"]
+                    == self.Conditions.Reason.CONFIGURATION_PROGRESSING
+                )
+            ):
                 return
 
     def wait_for_status_success(self):
@@ -368,7 +378,7 @@ class NodeNetworkConfigurationPolicy(Resource):
             )
 
         # if we get here too fast there are no conditions, we need to wait.
-        self._wait_for_configuration_progressing()
+        self._wait_for_configuration_conditions_unknown_or_progressing()
 
         samples = TimeoutSampler(wait_timeout=480, sleep=1, func=self.status)
         try:
